/*
FILE: memcardlib.h
DESCRIPTION: The memcardlib header file
WRITTEN BY: Derek Nedelman (nedelman@netzero.net)
DATE: August 21, 2002
HOME PAGE: http://www.playstation2-linux.com/projects/memcardlib
*/

#ifndef MEMCARDLIB_INCLUDED
#define MEMCARDLIB_INCLUDED


//Includes---------------------------------------------------------------------
#include <fcntl.h>		//linux/ps2/mcio.h needs this
#include <asm/types.h>		//linux/ps2/mcio.h needs this
#include <linux/ps2/mcio.h>


//Defines----------------------------------------------------------------------

//Used to check the card's status as returned by memcardlib_get_card_status()
#define PS2MC_STAT_NOTCON     	0x00
#define PS2MC_STAT_READY      	0x01
#define PS2MC_STAT_BUSY       	0x02
#define PS2MC_STAT_ERROR      	0x03


//Prototypes-------------------------------------------------------------------
void memcardlib_initialize(void);
void memcardlib_shutdown(void);

int memcardlib_num_supported_memcards(void);

int memcardlib_get_card_type(int card);
int memcardlib_get_card_status(int card);
void memcardlib_get_card_block_info(int card, int* block_size, int* total_blocks, int* free_blocks);
int memcardlib_is_card_formatted(int card);

void* memcardlib_open(int card, const char* name, int read_or_write);
void memcardlib_close(void* file);
int memcardlib_read(void* file, void* data, int num_bytes);
int memcardlib_write(void* file, const void* data, int num_bytes);
int memcardlib_get_pos(void* file);

int memcardlib_file_exists(int card, const char* name);
void memcardlib_delete_file(int card, const char* name);


#endif
